@@ -27,7 +27,15 @@ def hotspot(self, var_1, var_2, dropout_rm=True, use_grouped=False, cmap='viridi
     adata1 = Local_L(adata, var_1, var_2, dropout_rm=dropout_rm, max_RAM=32)
     adata.obs[f'{var_1} & {var_2}'] = adata1.uns['Local_L'].ravel()
     f, ax = plt.subplots(1,1, figsize=(4,4))
-    sc.pl.spatial(adata, color=f'{var_1} & {var_2}', ax=ax, cmap=cmap, alpha_img=alpha_img)
+    if self.data_type == 'visium':
+        sc.pl.spatial(adata, color=f'{var_1} & {var_2}', ax=ax, cmap=cmap, alpha_img=alpha_img)
+    else:
+        ax.scatter(x=adata.obs.x.copy(),
+                    y=adata.obs.y.copy(),
+                    c=np.ravel(adata.obs[f'{var_1} & {var_2}'].to_numpy()), cmap=cmap)
+        ax.axis("off")
+        ax.set_title(f'{var_1} & {var_2}')
+
     if use_grouped:
         self.grouped_adata = adata.copy()
     else:
