@@ -16,7 +16,9 @@ def load_raw(self, count_path, meta_path , visium_path):
     if os.path.exists(visium_path):
             self.visium_path = visium_path
             data = sc.read_visium(visium_path)
+            self.data_type = 'visium'
     elif os.path.exists(count_path) and os.path.exists(meta_path):
+        self.data_type = 'st'
         count = pd.read_csv(count_path, index_col=0)
         meta = pd.read_csv(meta_path, index_col=0)
         
@@ -31,7 +33,7 @@ def load_raw(self, count_path, meta_path , visium_path):
             
         data = ad.AnnData(X=csr_matrix(count.values),
                                 var=var_df, obs=meta)
-        data.adata.obsm = {'spatial': meta[['x', 'y']].values.copy()}
+        data.obsm = {'spatial': meta[['x', 'y']].values.copy()}
     else:
         sys.exit("Please either provide (1) a visium path or (2) paths to count matrix and meta file.")
 
@@ -263,7 +265,23 @@ def module_pattern(self, ncols=4, alpha_img=0.5, cmap='Reds'):
     adata = group_adata_by_genes(self, ct_dict=mod2gene, inplace=False)
 
     adata.obs.rename(columns={"ct": "module"}, inplace=True)
-    sc.pl.spatial(adata, color=modules, alpha_img=alpha_img, ncols=ncols, cmap=cmap)
+    if self.data_type == 'visium':
+        sc.pl.spatial(adata, color=modules, alpha_img=alpha_img, ncols=ncols, cmap=cmap)
+    else:
+        import math
+        f, axs = plt.subplots(math.ceil(len(modules)/ncols), ncols, figsize=(math.ceil(len(modules)/ncols)* 4, ncols * 4))
+        for i in range(len(modules)):
+            ax = axs.flatten()[i]
+            ax.scatter(x=self.adata.obs.x.copy(),
+                            y=self.adata.obs.y.copy(),
+                            c=np.ravel(self.adata[:, modules[i]].X.toarray()), cmap=cmap)
+            ax.axis("off")
+            ax.set_title(modules[i])
+
+        for ax in axs.flatten()[i]:
+            ax.axis("off")
+
+
 
 def module_hotspot(self, dropout_rm=True, alpha_img=0.5, cmap='Blues_r', ncols=4):
     mod2gene = self.module_dict['mod2gene'].copy()
@@ -279,10 +297,24 @@ def module_hotspot(self, dropout_rm=True, alpha_img=0.5, cmap='Blues_r', ncols=4
             mod1, mod2 = modules[i], modules[j]
             adata1 = Local_L(adata, mod1, mod2, dropout_rm=dropout_rm, max_RAM=32)
             adata.obs[f'{mod1} & {mod2}'] = adata1.uns['Local_L'].ravel() 
-            pairs.append(f'{mod1} & {mod2}')  
+            pairs.append(f'{mod1} & {mod2}') 
 
-    sc.pl.spatial(adata, 
+    if self.data_type == 'visium':
+        sc.pl.spatial(adata, 
                     color=pairs, 
                     cmap=cmap,
                     alpha_img=alpha_img, 
-                    ncols=ncols)
\ No newline at end of file
+                    ncols=ncols)
+    else:
+        import math
+        f, axs = plt.subplots(math.ceil(len(pairs)/ncols), ncols, figsize=(math.ceil(len(pairs)/ncols)* 4, ncols * 4))
+        for i in range(len(pairs)):
+            ax = axs.flatten()[i]
+            ax.scatter(x=adata.obs.x.copy(),
+                            y=adata.obs.y.copy(),
+                            c=np.ravel(adata.obs[pairs[i]].to_numpy()), cmap=cmap)
+            ax.axis("off")
+            ax.set_title(pairs[i])
+            
+        for ax in axs.flatten()[i]:
+            ax.axis("off")
\ No newline at end of file
