@@ -11,7 +11,7 @@ from ._utils import *
 from ._gmod import *
 from ._plotting import *
 
-class SG(object):
+class SEAGAL(object):
     """ Spatial Enrichment Analysis of Gene Association using L-index.
     """
     def __init__(self, 
